encoding: Improving structure and documentation of block helpers

This commit add several new helpers to simplify operations with
std::string:

- prependStringBlock
- makeStringBlock
- readString

The following functions are deprecated and their replacements:

- nonNegativeIntegerBlock (use makeNonNegativeIntegerBlock)
- prependBooleanBlock (use prependEmptyBlock)
- booleanBlock (use makeEmptyBlock)
- dataBlock (use makeBinaryBlock)
- nestedBlock (use makeNestedBlock)

Change-Id: Ic595ae64fc9c80c2c04e5fde1d8812e8b9debd60
Refs: #2951
diff --git a/src/key-locator.hpp b/src/key-locator.hpp
index 27b8d67..8c206e4 100644
--- a/src/key-locator.hpp
+++ b/src/key-locator.hpp
@@ -72,11 +72,11 @@
 
 public: // encode and decode
   /** \brief prepend wire encoding
    *  \param block EncodingBuffer or Estimator
    */
   template<encoding::Tag TAG>
   size_t
-  wireEncode(EncodingImpl<TAG>& block) const;
+  wireEncode(EncodingImpl<TAG>& encoder) const;
 
   /** \return wire encoding
    */
@@ -72,11 +72,11 @@
 public: // encode and decode
   /** \brief prepend wire encoding
-   *  \param block EncodingBuffer or Estimator
+   *  \param encoder EncodingBuffer or Estimator
    */
   template<encoding::Tag TAG>